Script 'mail_helper' called by obssrc
Hello community,

here is the log from the commit of package kalk for openSUSE:Factory checked in 
at 2023-08-31 13:44:06
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/kalk (Old)
 and      /work/SRC/openSUSE:Factory/.kalk.new.1766 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "kalk"

Thu Aug 31 13:44:06 2023 rev:5 rq:1105641 version:23.08.0

Changes:
--------
--- /work/SRC/openSUSE:Factory/kalk/kalk.changes        2023-07-07 
15:50:05.069183932 +0200
+++ /work/SRC/openSUSE:Factory/.kalk.new.1766/kalk.changes      2023-08-31 
13:47:18.571636404 +0200
@@ -1,0 +2,32 @@
+Sun Aug 20 13:59:07 UTC 2023 - Christophe Marin <[email protected]>
+
+- Update to 23.08.0
+  * New feature release
+  * For more details please see:
+  * https://kde.org/announcements/gear/23.08.0/
+- No code change since 23.07.90
+
+-------------------------------------------------------------------
+Mon Aug 14 08:02:24 UTC 2023 - Christophe Marin <[email protected]>
+
+- Update to 23.07.90
+  * New feature release
+- Changes since 23.07.80:
+  * flatpak: update runtime to 22.08
+
+-------------------------------------------------------------------
+Tue Aug  1 10:13:27 UTC 2023 - Christophe Marin <[email protected]>
+
+- Update to 23.07.80
+  * New feature release
+- Changes since 23.04.3:
+  * Allow building against KF6
+  * set float precision
+  * fix parse bug for locales using space group separator (kde#470439)
+  * knumber_float the precision is specified via setDefaultFloatPrecision
+  * Add more contrasting button background
+  * Fix window dimensions and readbility of text (kde#465208)
+  * Make history closeable in wide windows
+  * [CI] Add jobs for Android
+
+-------------------------------------------------------------------

Old:
----
  kalk-23.04.3.tar.xz
  kalk-23.04.3.tar.xz.sig

New:
----
  kalk-23.08.0.tar.xz
  kalk-23.08.0.tar.xz.sig

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ kalk.spec ++++++
--- /var/tmp/diff_new_pack.zEAo8v/_old  2023-08-31 13:47:19.687676293 +0200
+++ /var/tmp/diff_new_pack.zEAo8v/_new  2023-08-31 13:47:19.691676436 +0200
@@ -18,7 +18,7 @@
 
 %bcond_without  released
 Name:           kalk
-Version:        23.04.3
+Version:        23.08.0
 Release:        0
 Summary:        Convergent calculator
 License:        GPL-3.0-or-later


++++++ kalk-23.04.3.tar.xz -> kalk-23.08.0.tar.xz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/.flatpak-manifest.json 
new/kalk-23.08.0/.flatpak-manifest.json
--- old/kalk-23.04.3/.flatpak-manifest.json     2023-07-04 07:35:43.000000000 
+0200
+++ new/kalk-23.08.0/.flatpak-manifest.json     2023-08-16 23:31:12.000000000 
+0200
@@ -1,7 +1,7 @@
 {
     "id": "org.kde.kalk",
     "runtime": "org.kde.Platform",
-    "runtime-version": "5.15-21.08",
+    "runtime-version": "5.15-22.08",
     "sdk": "org.kde.Sdk",
     "command": "kalk",
     "tags": ["nightly"],
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/.gitlab-ci.yml 
new/kalk-23.08.0/.gitlab-ci.yml
--- old/kalk-23.04.3/.gitlab-ci.yml     2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/.gitlab-ci.yml     2023-08-16 23:31:12.000000000 +0200
@@ -8,3 +8,5 @@
   - 
https://invent.kde.org/sysadmin/ci-utilities/raw/master/gitlab-templates/freebsd.yml
   - 
https://invent.kde.org/sysadmin/ci-utilities/raw/master/gitlab-templates/freebsd-qt6.yml
   - 
https://invent.kde.org/sysadmin/ci-utilities/raw/master/gitlab-templates/flatpak.yml
+  - 
https://invent.kde.org/sysadmin/ci-utilities/raw/master/gitlab-templates/android.yml
+  - 
https://invent.kde.org/sysadmin/ci-utilities/raw/master/gitlab-templates/android-qt6.yml
\ No newline at end of file
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/.kde-ci.yml new/kalk-23.08.0/.kde-ci.yml
--- old/kalk-23.04.3/.kde-ci.yml        2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/.kde-ci.yml        2023-08-16 23:31:12.000000000 +0200
@@ -2,7 +2,7 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
 Dependencies:
-- 'on': ['@all']
+- 'on': ['Linux/Qt5', 'FreeBSD/Qt5', 'Android/Qt5']
   'require':
     'frameworks/extra-cmake-modules': '@stable'
     'frameworks/kcoreaddons': '@stable'
@@ -11,5 +11,14 @@
     'frameworks/kconfig': '@stable'
     'frameworks/kunitconversion': '@stable'
 
+- 'on': ['Linux/Qt6', 'FreeBSD/Qt6', 'Android/Qt6']
+  'require':
+    'frameworks/extra-cmake-modules': '@latest-kf6'
+    'frameworks/kcoreaddons': '@latest-kf6'
+    'frameworks/kirigami': '@latest-kf6'
+    'frameworks/ki18n': '@latest-kf6'
+    'frameworks/kconfig': '@latest-kf6'
+    'frameworks/kunitconversion': '@latest-kf6'
+
 Options:
     cppcheck-arguments: '--enable=warning,style,performance --inline-suppr 
--suppress=passedByValue --suppress=nullPointer'
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/CMakeLists.txt 
new/kalk-23.08.0/CMakeLists.txt
--- old/kalk-23.04.3/CMakeLists.txt     2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/CMakeLists.txt     2023-08-16 23:31:12.000000000 +0200
@@ -6,8 +6,8 @@
 
 # KDE Applications version, managed by release script.
 set(RELEASE_SERVICE_VERSION_MAJOR "23")
-set(RELEASE_SERVICE_VERSION_MINOR "04")
-set(RELEASE_SERVICE_VERSION_MICRO "3")
+set(RELEASE_SERVICE_VERSION_MINOR "08")
+set(RELEASE_SERVICE_VERSION_MICRO "0")
 set(RELEASE_SERVICE_VERSION 
"${RELEASE_SERVICE_VERSION_MAJOR}.${RELEASE_SERVICE_VERSION_MINOR}.${RELEASE_SERVICE_VERSION_MICRO}")
 
 project(kalk VERSION ${RELEASE_SERVICE_VERSION})
@@ -16,7 +16,7 @@
 find_package(FLEX REQUIRED)
 
 
-set(KF5_MIN_VERSION "5.89.0")
+set(KF_MIN_VERSION "5.89.0")
 set(QT_MIN_VERSION "5.15.2")
 if (ANDROID)
     set(QT_MIN_VERSION "5.15.8")
@@ -32,7 +32,7 @@
 # only enable QML debugging on debug builds
 set(CMAKE_CXX_FLAGS_DEBUG "${CMAKE_CXX_FLAGS_DEBUG} -DQT_QML_DEBUG ")
 
-find_package(ECM ${KF5_MIN_VERSION} REQUIRED NO_MODULE)
+find_package(ECM ${KF_MIN_VERSION} REQUIRED NO_MODULE)
 set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} ${ECM_MODULE_PATH} 
${CMAKE_SOURCE_DIR}/cmake/modules)
 
 find_package(GMP)
@@ -78,7 +78,7 @@
 
 find_package(Qt${QT_MAJOR_VERSION} ${QT_MIN_VERSION} REQUIRED NO_MODULE 
COMPONENTS Core Quick Test Gui QuickControls2 Widgets)
 find_package(Qt${QT_MAJOR_VERSION} ${QT_MIN_VERSION} NO_MODULE COMPONENTS 
QuickCompiler)
-find_package(KF5 ${KF5_MIN_VERSION} REQUIRED COMPONENTS
+find_package(KF${QT_MAJOR_VERSION} ${KF_MIN_VERSION} REQUIRED COMPONENTS
         Config
         Kirigami2
         I18n
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/knumber/knumber_float.cpp 
new/kalk-23.08.0/knumber/knumber_float.cpp
--- old/kalk-23.04.3/knumber/knumber_float.cpp  2023-07-04 07:35:43.000000000 
+0200
+++ new/kalk-23.08.0/knumber/knumber_float.cpp  2023-08-16 23:31:12.000000000 
+0200
@@ -129,7 +129,7 @@
 }
 
 mpfr_ptr knumber_float::new_mpfr() {
-    mpfr_init2(mpfr_, precision);
+    mpfr_init(mpfr_);
     return mpfr_;
 }
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/org.kde.kalk.appdata.xml 
new/kalk-23.08.0/org.kde.kalk.appdata.xml
--- old/kalk-23.04.3/org.kde.kalk.appdata.xml   2023-07-04 07:35:43.000000000 
+0200
+++ new/kalk-23.08.0/org.kde.kalk.appdata.xml   2023-08-16 23:31:12.000000000 
+0200
@@ -18,6 +18,7 @@
   <name xml:lang="de">Calculator</name>
   <name xml:lang="el">Αριθμομηχανή</name>
   <name xml:lang="en-GB">Calculator</name>
+  <name xml:lang="eo">Calculator</name>
   <name xml:lang="es">Calculadora</name>
   <name xml:lang="eu">Kalkulagailua</name>
   <name xml:lang="fi">Laskin</name>
@@ -52,6 +53,7 @@
   <summary xml:lang="de">Ein leistungsfähiger Rechner</summary>
   <summary xml:lang="el">Μια αριθμομηχανή πλούσια σε 
χαρακτηριστικά</summary>
   <summary xml:lang="en-GB">A feature rich calculator</summary>
+  <summary xml:lang="eo">Multkapabla kalkulilo</summary>
   <summary xml:lang="es">Una calculadora con numerosas funciones</summary>
   <summary xml:lang="eu">Ezaugarritan aberatsa den kalkulagailua bat</summary>
   <summary xml:lang="fi">Monipuolinen laskin</summary>
@@ -87,6 +89,7 @@
   <developer_name xml:lang="de">KDE-Gemeinschaft</developer_name>
   <developer_name xml:lang="el">Η Κοινότητα του 
KDE</developer_name>
   <developer_name xml:lang="en-GB">KDE Community</developer_name>
+  <developer_name xml:lang="eo">KDE-Komunumo</developer_name>
   <developer_name xml:lang="es">Comunidad KDE</developer_name>
   <developer_name xml:lang="eu">KDE komunitatea</developer_name>
   <developer_name xml:lang="fi">KDE-yhteisö</developer_name>
@@ -122,6 +125,7 @@
     <p xml:lang="de">Kalk ist ein konvergenter Rechner für Plasma.</p>
     <p xml:lang="el">Το Kalk είναι μια αριθμομηχανή 
για το Plasma.</p>
     <p xml:lang="en-GB">Kalk is a convergent calculator for Plasma.</p>
+    <p xml:lang="eo">Kalk estas konverĝa kalkulilopor Plasma.</p>
     <p xml:lang="es">Kalk es una calculadora convergente para Plasma.</p>
     <p xml:lang="eu">Kalk, Plasmarako kalkulagailu konbergente bat da.</p>
     <p xml:lang="fi">Kalk on mukautuva laskin Plasmaan.</p>
@@ -157,6 +161,7 @@
       <caption xml:lang="de">Calculator-Seite</caption>
       <caption xml:lang="el">Η σελίδα του Kalk</caption>
       <caption xml:lang="en-GB">Calculator Page</caption>
+      <caption xml:lang="eo">Kalkulila Paĝo</caption>
       <caption xml:lang="es">Página de la calculadora</caption>
       <caption xml:lang="eu">Kalkulagailu-orria</caption>
       <caption xml:lang="fi">Laskinsivu</caption>
@@ -202,6 +207,7 @@
   <url type="homepage">https://invent.kde.org/plasma-mobile/kalk</url>
   <url type="bugtracker">https://bugs.kde.org/enter_bug.cgi?product=Kalk</url>
   <releases>
+    <release version="23.08.0" date="2023-08-24"/>
     <release version="23.04.3" date="2023-07-06"/>
     <release version="23.04.2" date="2023-06-08"/>
     <release version="23.04.1" date="2023-05-11"/>
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/org.kde.kalk.desktop 
new/kalk-23.08.0/org.kde.kalk.desktop
--- old/kalk-23.04.3/org.kde.kalk.desktop       2023-07-04 07:35:43.000000000 
+0200
+++ new/kalk-23.08.0/org.kde.kalk.desktop       2023-08-16 23:31:12.000000000 
+0200
@@ -11,6 +11,7 @@
 Name[de]=Rechner
 Name[el]=Αριθμομηχανή
 Name[en_GB]=Calculator
+Name[eo]=Calculator
 Name[es]=Calculadora
 Name[eu]=Kalkulagailua
 Name[fi]=Laskin
@@ -44,6 +45,7 @@
 Comment[de]=Ein leistungsfähiger Rechner
 Comment[el]=Μια αριθμομηχανή πλούσια σε 
χαρακτηριστικά
 Comment[en_GB]=A feature rich calculator
+Comment[eo]=Multkapabla kalkulilo
 Comment[es]=Una calculadora con muchas funciones
 Comment[eu]=Ezaugarritan aberatsa den kalkulagailua bat
 Comment[fi]=Monipuolinen laskin
@@ -81,6 +83,7 @@
 Keywords[de]=Rechner;
 Keywords[el]=Αριθμομηχανή;Kalk;
 Keywords[en_GB]=Calculator;Kalk;
+Keywords[eo]=Kalkulilo;Kalk;
 Keywords[es]=Calculadora;Kalk;
 Keywords[eu]=Kalkulagailua;Kalk;
 Keywords[fi]=Laskin;Kalk;
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/ar/kalk.po 
new/kalk-23.08.0/po/ar/kalk.po
--- old/kalk-23.04.3/po/ar/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/ar/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-23 20:22+0400\n"
 "Last-Translator: Zayed Al-Saidi <[email protected]>\n"
 "Language-Team: ar\n"
@@ -28,18 +28,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "حاسبة"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "حاسبة لبلازما"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 مجتمع كِيدِي"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/az/kalk.po 
new/kalk-23.08.0/po/az/kalk.po
--- old/kalk-23.04.3/po/az/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/az/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -1,13 +1,13 @@
 # Copyright (C) YEAR This file is copyright:
 # This file is distributed under the same license as the kalk package.
 #
-# Kheyyam <[email protected]>, 2022.
+# Kheyyam <[email protected]>, 2022, 2023.
 msgid ""
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
-"PO-Revision-Date: 2022-06-26 13:31+0400\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
+"PO-Revision-Date: 2023-06-30 13:42+0400\n"
 "Last-Translator: Kheyyam <[email protected]>\n"
 "Language-Team: Azerbaijani <[email protected]>\n"
 "Language: az\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Lokalize 22.04.2\n"
+"X-Generator: Lokalize 23.04.2\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
@@ -27,23 +27,21 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Hesablayıcı"
 
-#: main.cpp:56
-#, fuzzy, kde-format
-#| msgid "Calculator in Kirigami"
+#: main.cpp:65
+#, kde-format
 msgid "Calculator for Plasma"
-msgstr "Hesablayıcı Kirigami-də"
+msgstr "Plasma üçün hesablayıcı"
 
-#: main.cpp:58
-#, fuzzy, kde-format
-#| msgid "© 2020-2021 KDE Community"
+#: main.cpp:67
+#, kde-format
 msgid "© 2020-2022 KDE Community"
-msgstr "© 2020-2021 KDE Cəmiyyəti"
+msgstr "© 2020-2022 KDE Cəmiyyəti"
 
 #: qml/AboutPage.qml:19 qml/main.qml:91 qml/main.qml:180
 #, kde-format
@@ -71,8 +69,7 @@
 msgstr "Jurnalı təmizləyin"
 
 #: qml/main.qml:77 qml/main.qml:138
-#, fuzzy, kde-format
-#| msgid "Convertor"
+#, kde-format
 msgid "Converter"
 msgstr "Çevirici"
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/ca/kalk.po 
new/kalk-23.08.0/po/ca/kalk.po
--- old/kalk-23.04.3/po/ca/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/ca/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-18 09:32+0100\n"
 "Last-Translator: Josep M. Ferrer <[email protected]>\n"
 "Language-Team: Catalan <[email protected]>\n"
@@ -30,18 +30,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Calculadora"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Una calculadora per al Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 La comunitat KDE"
@@ -85,6 +85,3 @@
 #, kde-format
 msgid "Swap"
 msgstr "Intercanvia"
-
-#~ msgid "copied"
-#~ msgstr "s'ha copiat"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/ca@valencia/kalk.po 
new/kalk-23.08.0/po/ca@valencia/kalk.po
--- old/kalk-23.04.3/po/ca@valencia/kalk.po     2023-07-04 07:35:43.000000000 
+0200
+++ new/kalk-23.08.0/po/ca@valencia/kalk.po     2023-08-16 23:31:12.000000000 
+0200
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-18 09:32+0100\n"
 "Last-Translator: Josep M. Ferrer <[email protected]>\n"
 "Language-Team: Catalan <[email protected]>\n"
@@ -30,18 +30,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Calculadora"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Una calculadora per a Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 La comunitat KDE"
@@ -85,6 +85,3 @@
 #, kde-format
 msgid "Swap"
 msgstr "Intercanvia"
-
-#~ msgid "copied"
-#~ msgstr "s'ha copiat"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/cs/kalk.po 
new/kalk-23.08.0/po/cs/kalk.po
--- old/kalk-23.04.3/po/cs/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/cs/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-24 15:33+0100\n"
 "Last-Translator: Vit Pelcak <[email protected]>\n"
 "Language-Team: Czech <[email protected]>\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Kalkulačka"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Kalkulačka pro Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 Komunita KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/de/kalk.po 
new/kalk-23.08.0/po/de/kalk.po
--- old/kalk-23.04.3/po/de/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/de/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-02-04 00:36+0100\n"
 "Last-Translator: Frank Steinmetzger <[email protected]>\n"
 "Language-Team: German <[email protected]>\n"
@@ -29,18 +29,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Rechner"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Rechner in Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "Copyright © 2020-2022 KDE-Gemeinschaft"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/el/kalk.po 
new/kalk-23.08.0/po/el/kalk.po
--- old/kalk-23.04.3/po/el/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/el/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-05 10:37+0200\n"
 "Last-Translator: Stelios <[email protected]>\n"
 "Language-Team: Greek <[email protected]>\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Αριθμομηχανή"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Αριθμομηχανή για το Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 Η Κοινότητα του KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/en_GB/kalk.po 
new/kalk-23.08.0/po/en_GB/kalk.po
--- old/kalk-23.04.3/po/en_GB/kalk.po   2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/en_GB/kalk.po   2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-02-26 19:45+0000\n"
 "Last-Translator: Steve Allewell <[email protected]>\n"
 "Language-Team: British English\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Calculator"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Calculator for Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 KDE Community"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/es/kalk.po 
new/kalk-23.08.0/po/es/kalk.po
--- old/kalk-23.04.3/po/es/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/es/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-18 14:50+0100\n"
 "Last-Translator: Eloy Cuadra <[email protected]>\n"
 "Language-Team: Spanish <[email protected]>\n"
@@ -29,18 +29,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Calculadora"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Calculadora para Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 la Comunidad de KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/eu/kalk.po 
new/kalk-23.08.0/po/eu/kalk.po
--- old/kalk-23.04.3/po/eu/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/eu/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-20 19:02+0100\n"
 "Last-Translator: Iñigo Salvador Azurmendi <[email protected]>\n"
 "Language-Team: Basque <[email protected]>\n"
@@ -30,18 +30,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Kalkulagailua"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Plasmarako kalkulagailua"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 KDE komunitatea"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/fi/kalk.po 
new/kalk-23.08.0/po/fi/kalk.po
--- old/kalk-23.04.3/po/fi/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/fi/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-02-26 19:21+0200\n"
 "Last-Translator: Tommi Nieminen <[email protected]>\n"
 "Language-Team: Finnish <[email protected]>\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Laskin"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Laskin Plasmaan"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020–2022 KDE-yhteisö"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/fr/kalk.po 
new/kalk-23.08.0/po/fr/kalk.po
--- old/kalk-23.04.3/po/fr/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/fr/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -4,7 +4,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-20 18:57+0100\n"
 "Last-Translator: Xavier BESNARD <xavier.besnard]neuf.fr>\n"
 "Language-Team: fr\n"
@@ -25,18 +25,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Calculatrice"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Une calculatrice pour Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 Communauté KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/gl/kalk.po 
new/kalk-23.08.0/po/gl/kalk.po
--- old/kalk-23.04.3/po/gl/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/gl/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-05-01 10:41+0200\n"
 "Last-Translator: Adrián Chaves (Gallaecio) <[email protected]>\n"
 "Language-Team: Galician <[email protected]>\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Calculadora"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Calculadora para Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 Comunidade KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/hi/kalk.po 
new/kalk-23.08.0/po/hi/kalk.po
--- old/kalk-23.04.3/po/hi/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/hi/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2022-02-10 11:32+0530\n"
 "Last-Translator: Raghavendra Kamath <[email protected]>\n"
 "Language-Team: Hindi <[email protected]>\n"
@@ -28,19 +28,19 @@
 msgid "Your emails"
 msgstr "[email protected], [email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "गणक"
 
-#: main.cpp:56
+#: main.cpp:65
 #, fuzzy, kde-format
 #| msgid "Calculator in Kirigami"
 msgid "Calculator for Plasma"
 msgstr "किरिगामी में एक गणक"
 
-#: main.cpp:58
+#: main.cpp:67
 #, fuzzy, kde-format
 #| msgid "© 2020-2021 KDE Community"
 msgid "© 2020-2022 KDE Community"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/hu/kalk.po 
new/kalk-23.08.0/po/hu/kalk.po
--- old/kalk-23.04.3/po/hu/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/hu/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2020-12-29 14:55+0100\n"
 "Last-Translator: Kristóf Kiszel <[email protected]>\n"
 "Language-Team: Hungarian <[email protected]>\n"
@@ -27,19 +27,19 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Számológép"
 
-#: main.cpp:56
+#: main.cpp:65
 #, fuzzy, kde-format
 #| msgid "Calculator in Kirigami"
 msgid "Calculator for Plasma"
 msgstr "Számológép Kirigamiban"
 
-#: main.cpp:58
+#: main.cpp:67
 #, fuzzy, kde-format
 #| msgid "© 2020 KDE Community"
 msgid "© 2020-2022 KDE Community"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/it/kalk.po 
new/kalk-23.08.0/po/it/kalk.po
--- old/kalk-23.04.3/po/it/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/it/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-20 08:40+0100\n"
 "Last-Translator: Paolo Zamponi <[email protected]>\n"
 "Language-Team: Italian <[email protected]>\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Calcolatrice"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Calcolatrice per Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 Comunità KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/ja/kalk.po 
new/kalk-23.08.0/po/ja/kalk.po
--- old/kalk-23.04.3/po/ja/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/ja/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -2,7 +2,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2020-08-02 21:58-0700\n"
 "Last-Translator: Japanese KDE translation team <[email protected]>\n"
 "Language-Team: Japanese <[email protected]>\n"
@@ -24,18 +24,18 @@
 msgid "Your emails"
 msgstr ""
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr ""
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr ""
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr ""
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/ka/kalk.po 
new/kalk-23.08.0/po/ka/kalk.po
--- old/kalk-23.04.3/po/ka/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/ka/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-19 07:35+0100\n"
 "Last-Translator: Temuri Doghonadze <[email protected]>\n"
 "Language-Team: Georgian <[email protected]>\n"
@@ -28,18 +28,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "კალკულატორი"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "კალკულატორი Plasma-სთვის"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 KDE-ის საზოგადოება"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/ko/kalk.po 
new/kalk-23.08.0/po/ko/kalk.po
--- old/kalk-23.04.3/po/ko/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/ko/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-04-21 23:58+0200\n"
 "Last-Translator: Shinjo Park <[email protected]>\n"
 "Language-Team: Korean <[email protected]>\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "계산기"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Plasma용 계산기"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 KDE Community"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/lt/kalk.po 
new/kalk-23.08.0/po/lt/kalk.po
--- old/kalk-23.04.3/po/lt/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/lt/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2020-08-21 02:26+0200\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -28,18 +28,18 @@
 msgid "Your emails"
 msgstr ""
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr ""
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr ""
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr ""
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/nl/kalk.po 
new/kalk-23.08.0/po/nl/kalk.po
--- old/kalk-23.04.3/po/nl/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/nl/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-19 17:15+0100\n"
 "Last-Translator: Freek de Kruijf <[email protected]>\n"
 "Language-Team: \n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Rekenmachine"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Rekenmachine voor Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 KDE gemeenschap"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/nn/kalk.po 
new/kalk-23.08.0/po/nn/kalk.po
--- old/kalk-23.04.3/po/nn/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/nn/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-02-09 21:44+0100\n"
 "Last-Translator: Karl Ove Hufthammer <[email protected]>\n"
 "Language-Team: Norwegian Nynorsk <[email protected]>\n"
@@ -30,18 +30,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Kalkulator"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Kalkulator for Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020–2022 KDE-fellesskapet"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/pa/kalk.po 
new/kalk-23.08.0/po/pa/kalk.po
--- old/kalk-23.04.3/po/pa/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/pa/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2021-01-20 21:43-0800\n"
 "Last-Translator: A S Alam <[email protected]>\n"
 "Language-Team: Punjabi <[email protected]>\n"
@@ -27,19 +27,19 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "ਕੈਲਕੂਲੇਟਰ"
 
-#: main.cpp:56
+#: main.cpp:65
 #, fuzzy, kde-format
 #| msgid "Calculator in Kirigami"
 msgid "Calculator for Plasma"
 msgstr "ਕੀਰੀਗਾਮੀ ਵਿੱਚ ਕੈਲਕੂਲੇਟਰ"
 
-#: main.cpp:58
+#: main.cpp:67
 #, fuzzy, kde-format
 #| msgid "© 2020 KDE Community"
 msgid "© 2020-2022 KDE Community"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/pl/kalk.po 
new/kalk-23.08.0/po/pl/kalk.po
--- old/kalk-23.04.3/po/pl/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/pl/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-02-12 09:42+0100\n"
 "Last-Translator: Łukasz Wojniłowicz <[email protected]>\n"
 "Language-Team: Polish <[email protected]>\n"
@@ -28,18 +28,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Kalkulator"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Kalkulator dla Plazmy"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 Społeczność KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/pt/kalk.po 
new/kalk-23.08.0/po/pt/kalk.po
--- old/kalk-23.04.3/po/pt/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/pt/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -2,7 +2,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-18 13:35+0000\n"
 "Last-Translator: José Nuno Coelho Pires <[email protected]>\n"
 "Language-Team: Portuguese <[email protected]>\n"
@@ -23,18 +23,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Calculadora"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Calculadora do Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 da Comunidade do KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/pt_BR/kalk.po 
new/kalk-23.08.0/po/pt_BR/kalk.po
--- old/kalk-23.04.3/po/pt_BR/kalk.po   2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/pt_BR/kalk.po   2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-02-07 10:46-0300\n"
 "Last-Translator: Luiz Fernando Ranghetti <[email protected]>\n"
 "Language-Team: Portuguese <[email protected]>\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Calculadora"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Calculadora para o Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 Comunidade KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/ru/kalk.po 
new/kalk-23.08.0/po/ru/kalk.po
--- old/kalk-23.04.3/po/ru/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/ru/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,8 +6,8 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
-"PO-Revision-Date: 2023-04-21 14:56+0300\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
+"PO-Revision-Date: 2023-04-21 14:58+0300\n"
 "Last-Translator: Olesya Gerasimenko <[email protected]>\n"
 "Language-Team: Basealt Translation Team\n"
 "Language: ru\n"
@@ -28,18 +28,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Калькулятор"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Калькулятор для Plasma"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© Сообщество KDE, 2020-2022"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/sk/kalk.po 
new/kalk-23.08.0/po/sk/kalk.po
--- old/kalk-23.04.3/po/sk/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/sk/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -4,7 +4,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2022-04-18 17:53+0200\n"
 "Last-Translator: Roman Paholik <[email protected]>\n"
 "Language-Team: Slovak <[email protected]>\n"
@@ -25,19 +25,19 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Kalkulačka"
 
-#: main.cpp:56
+#: main.cpp:65
 #, fuzzy, kde-format
 #| msgid "Calculator in Kirigami"
 msgid "Calculator for Plasma"
 msgstr "Kalkulačka v Kirigami"
 
-#: main.cpp:58
+#: main.cpp:67
 #, fuzzy, kde-format
 #| msgid "© 2020-2021 KDE Community"
 msgid "© 2020-2022 KDE Community"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/sl/kalk.po 
new/kalk-23.08.0/po/sl/kalk.po
--- old/kalk-23.04.3/po/sl/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/sl/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-19 09:13+0100\n"
 "Last-Translator: Matjaž Jeran <[email protected]>\n"
 "Language-Team: Slovenian <[email protected]>\n"
@@ -28,18 +28,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Kalkulator"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Kalkulator za Plasmo"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 Skupnost KDE"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/sv/kalk.po 
new/kalk-23.08.0/po/sv/kalk.po
--- old/kalk-23.04.3/po/sv/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/sv/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -1,13 +1,13 @@
 # Copyright (C) YEAR This file is copyright:
 # This file is distributed under the same license as the kalk package.
 #
-# Stefan Asserhäll <[email protected]>, 2020, 2021, 2022.
+# Stefan Asserhäll <[email protected]>, 2020, 2021, 2022, 2023.
 msgid ""
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
-"PO-Revision-Date: 2022-09-25 10:00+0200\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
+"PO-Revision-Date: 2023-07-24 11:30+0200\n"
 "Last-Translator: Stefan Asserhäll <[email protected]>\n"
 "Language-Team: Swedish <[email protected]>\n"
 "Language: sv\n"
@@ -27,23 +27,21 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Räknare"
 
-#: main.cpp:56
-#, fuzzy, kde-format
-#| msgid "Calculator in Kirigami"
+#: main.cpp:65
+#, kde-format
 msgid "Calculator for Plasma"
-msgstr "Räknare i Kirigami"
+msgstr "Räknare för Plasma"
 
-#: main.cpp:58
-#, fuzzy, kde-format
-#| msgid "© 2020-2021 KDE Community"
+#: main.cpp:67
+#, kde-format
 msgid "© 2020-2022 KDE Community"
-msgstr "© 2020-2021 KDE-gemenskapen"
+msgstr "© 2020-2022 KDE-gemenskapen"
 
 #: qml/AboutPage.qml:19 qml/main.qml:91 qml/main.qml:180
 #, kde-format
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/tr/kalk.po 
new/kalk-23.08.0/po/tr/kalk.po
--- old/kalk-23.04.3/po/tr/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/tr/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-18 20:47+0300\n"
 "Last-Translator: Emir SARI <[email protected]>\n"
 "Language-Team: Turkish <[email protected]>\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Hesap Makinesi"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Plasma için Hesap Makinesi"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 KDE Community"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/uk/kalk.po 
new/kalk-23.08.0/po/uk/kalk.po
--- old/kalk-23.04.3/po/uk/kalk.po      2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/uk/kalk.po      2023-08-16 23:31:12.000000000 +0200
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2023-01-18 11:54+0200\n"
 "Last-Translator: Yuri Chornoivan <[email protected]>\n"
 "Language-Team: Ukrainian <[email protected]>\n"
@@ -30,18 +30,18 @@
 msgid "Your emails"
 msgstr "[email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "Калькулятор"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "Калькулятор для Плазми"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© Спільнота KDE, 2020–2022"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/zh_CN/kalk.po 
new/kalk-23.08.0/po/zh_CN/kalk.po
--- old/kalk-23.04.3/po/zh_CN/kalk.po   2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/zh_CN/kalk.po   2023-08-16 23:31:12.000000000 +0200
@@ -2,8 +2,8 @@
 msgstr ""
 "Project-Id-Version: kdeorg\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
-"PO-Revision-Date: 2023-07-03 11:41\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
+"PO-Revision-Date: 2023-08-02 12:45\n"
 "Last-Translator: \n"
 "Language-Team: Chinese Simplified\n"
 "Language: zh_CN\n"
@@ -27,18 +27,18 @@
 msgid "Your emails"
 msgstr "[email protected], [email protected], [email protected]"
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr "计算器"
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr "为 Plasma 设计的计算器程序"
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr "© 2020-2022 KDE Community"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/po/zh_TW/kalk.po 
new/kalk-23.08.0/po/zh_TW/kalk.po
--- old/kalk-23.04.3/po/zh_TW/kalk.po   2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/po/zh_TW/kalk.po   2023-08-16 23:31:12.000000000 +0200
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: kalk\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n";
-"POT-Creation-Date: 2023-03-04 00:49+0000\n"
+"POT-Creation-Date: 2023-03-27 00:52+0000\n"
 "PO-Revision-Date: 2022-06-02 00:47+0000\n"
 "Last-Translator: Automatically generated\n"
 "Language-Team: none\n"
@@ -28,18 +28,18 @@
 msgid "Your emails"
 msgstr ""
 
-#: main.cpp:54 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
+#: main.cpp:63 qml/CalculationPage.qml:16 qml/main.qml:70 qml/main.qml:111
 #: qml/main.qml:114 qml/main.qml:120
 #, kde-format
 msgid "Calculator"
 msgstr ""
 
-#: main.cpp:56
+#: main.cpp:65
 #, kde-format
 msgid "Calculator for Plasma"
 msgstr ""
 
-#: main.cpp:58
+#: main.cpp:67
 #, kde-format
 msgid "© 2020-2022 KDE Community"
 msgstr ""
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/src/CMakeLists.txt 
new/kalk-23.08.0/src/CMakeLists.txt
--- old/kalk-23.04.3/src/CMakeLists.txt 2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/src/CMakeLists.txt 2023-08-16 23:31:12.000000000 +0200
@@ -35,16 +35,16 @@
     Qt::Core
     Qt::Qml
     Qt::QuickControls2
-    KF5::UnitConversion
-    KF5::ConfigCore
-    KF5::I18n
-    KF5::CoreAddons
+    KF${QT_MAJOR_VERSION}::UnitConversion
+    KF${QT_MAJOR_VERSION}::ConfigCore
+    KF${QT_MAJOR_VERSION}::I18n
+    KF${QT_MAJOR_VERSION}::CoreAddons
     kalklib
     knumber)
 
 if(ANDROID)
     target_link_libraries(kalk PRIVATE
-        KF5::Kirigami2
+        KF${QT_MAJOR_VERSION}::Kirigami2
         Qt::Svg
         OpenSSL::SSL
     )
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/src/inputmanager.cpp 
new/kalk-23.08.0/src/inputmanager.cpp
--- old/kalk-23.04.3/src/inputmanager.cpp       2023-07-04 07:35:43.000000000 
+0200
+++ new/kalk-23.08.0/src/inputmanager.cpp       2023-08-16 23:31:12.000000000 
+0200
@@ -17,6 +17,11 @@
 
     QLocale locale;
     m_groupSeparator = locale.groupSeparator();
+
+    // change non breaking space into classic space, because UI converts it to 
classic space
+    if (m_groupSeparator == QString(QChar(160))) {
+        m_groupSeparator = QLatin1Char(32);
+    }
     m_decimalPoint = locale.decimalPoint();
 }
 
@@ -147,6 +152,7 @@
 
     QString temp = m_input;
     temp.insert(m_inputPosition, subexpression);
+    temp.remove(m_groupSeparator);
 
     // Call the corresponding parser based on the type of expression.
     MathEngine * engineInstance = MathEngine::inst();
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/src/main.cpp 
new/kalk-23.08.0/src/main.cpp
--- old/kalk-23.04.3/src/main.cpp       2023-07-04 07:35:43.000000000 +0200
+++ new/kalk-23.08.0/src/main.cpp       2023-08-16 23:31:12.000000000 +0200
@@ -3,7 +3,6 @@
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
-#include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QIcon>
@@ -12,6 +11,12 @@
 #include <QQmlContext>
 #include <QQuickStyle>
 
+#ifdef Q_OS_ANDROID
+#include <QGuiApplication>
+#else
+#include <QApplication>
+#endif
+
 #include <KAboutData>
 #include <KLocalizedContext>
 #include <KLocalizedString>
@@ -27,7 +32,16 @@
 #endif
 int main(int argc, char *argv[])
 {
-    // set default style
+    QCommandLineParser parser;
+
+    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#ifdef Q_OS_ANDROID
+    QGuiApplication app(argc, argv);
+    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
+#else
+    QApplication app(argc, argv);
+    // set default style and icon theme
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
@@ -35,12 +49,7 @@
     if (qEnvironmentVariableIsEmpty("QT_QPA_PLATFORMTHEME")) {
         qputenv("QT_QPA_PLATFORMTHEME", "kde");
     }
-
-    QCommandLineParser parser;
-
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QApplication app(argc, argv);
-
+#endif
     QQmlApplicationEngine engine;
     KLocalizedString::setApplicationDomain("kalk");
     parser.addVersionOption();
@@ -74,6 +83,6 @@
 
     // required for X11
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.kalk")));
-
+    KNumber::setDefaultFloatPrecision(1000);
     return app.exec();
 }
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kalk-23.04.3/src/qml/CalculationPage.qml 
new/kalk-23.08.0/src/qml/CalculationPage.qml
--- old/kalk-23.04.3/src/qml/CalculationPage.qml        2023-07-04 
07:35:43.000000000 +0200
+++ new/kalk-23.08.0/src/qml/CalculationPage.qml        2023-08-16 
23:31:12.000000000 +0200
@@ -18,12 +18,17 @@
     leftPadding: 0
     rightPadding: 0
     bottomPadding: 0
-    
+
     actions.main: Kirigami.Action {
         text: i18n("History")
         iconName: "shallow-history"
         onTriggered: {
-            applicationWindow().pageStack.push("qrc:/qml/HistoryView.qml");
+            if (applicationWindow().pageStack.depth > 1) {
+                applicationWindow().pageStack.pop();
+            }
+            else {
+                applicationWindow().pageStack.push("qrc:/qml/HistoryView.qml");
+            };
             functionDrawer.close();
         }
     }
@@ -265,17 +270,17 @@
                         }
                     }
                 }
-                
+
                 // answer row
                 Flickable {
                     anchors.bottom: parent.bottom
                     anchors.right: parent.right
                     anchors.leftMargin: Kirigami.Units.largeSpacing * 2
                     anchors.rightMargin: Kirigami.Units.largeSpacing * 2
-                    
+
                     height: contentHeight
                     width: Math.min(parent.width - Kirigami.Units.largeSpacing 
* 2, contentWidth)
-                    
+
                     contentHeight: result.height
                     contentWidth: result.width
                     flickableDirection: Flickable.HorizontalFlick
@@ -327,7 +332,7 @@
             RowLayout {
                 Layout.fillHeight: true
                 Layout.fillWidth: true
-            
+
                 onWidthChanged: {
                     if (!functionDrawer.opened && inPortrait)
                         drawerIndicator.x = this.width - drawerIndicator.width 
+ drawerIndicator.radius;

Reply via email to